package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcBjsjwp;
import org.apache.ibatis.annotations.Param;

/**
 * 本级上级网评指令比例（月）Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcBjsjwpMapper 
{
    /**
     * 查询本级上级网评指令比例（月）
     * 
     * @param id 本级上级网评指令比例（月）主键
     * @return 本级上级网评指令比例（月）
     */
    public TcBjsjwp selectTcBjsjwpById(Long id);

    /**
     * 查询本级上级网评指令比例（月）列表
     * 
     * @param tcBjsjwp 本级上级网评指令比例（月）
     * @return 本级上级网评指令比例（月）集合
     */
    public List<TcBjsjwp> selectTcBjsjwpList(TcBjsjwp tcBjsjwp);

    /**
     * 新增本级上级网评指令比例（月）
     * 
     * @param tcBjsjwp 本级上级网评指令比例（月）
     * @return 结果
     */
    public int insertTcBjsjwp(TcBjsjwp tcBjsjwp);

    /**
     * 修改本级上级网评指令比例（月）
     * 
     * @param tcBjsjwp 本级上级网评指令比例（月）
     * @return 结果
     */
    public int updateTcBjsjwp(TcBjsjwp tcBjsjwp);

    /**
     * 删除本级上级网评指令比例（月）
     * 
     * @param id 本级上级网评指令比例（月）主键
     * @return 结果
     */
    public int deleteTcBjsjwpById(Long id);

    /**
     * 批量删除本级上级网评指令比例（月）
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcBjsjwpByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
