package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcAqyh;
import com.ruoyi.tcZz.domain.TcWljg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcBjsjwp;
import com.ruoyi.tcZz.service.ITcBjsjwpService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 本级上级网评指令比例（月）Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@Api(tags = "本级上级网评指令比例（月）")
@RestController
@RequestMapping("/tcZz/networkEcology/bjsjwp")
public class TcBjsjwpController extends BaseController
{
    @Autowired
    private ITcBjsjwpService tcBjsjwpService;

    /**
     * 查询本级上级网评指令比例（月）列表
     */
    @ApiOperation(value = "查询本级上级网评指令比例（月）列表",response = TcBjsjwp.class )
    @GetMapping("/list")
    public TableDataInfo list(TcBjsjwp tcBjsjwp)
    {
        startPage();
        List<TcBjsjwp> list = tcBjsjwpService.selectTcBjsjwpList(tcBjsjwp);
        return getDataTable(list);
    }

    /**
     * 导出本级上级网评指令比例（月）列表
     */
    @ApiOperation(value = "导出本级上级网评指令比例（月）列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcBjsjwp tcBjsjwp)
    {
        List<TcBjsjwp> list = tcBjsjwpService.selectTcBjsjwpList(tcBjsjwp);
        ExcelUtil<TcBjsjwp> util = new ExcelUtil<TcBjsjwp>(TcBjsjwp.class);
        util.exportExcel(response, list, "本级上级网评指令比例（月）数据");
    }

    /**
     * 获取本级上级网评指令比例（月）详细信息
     */
    @ApiOperation(value = "获取本级上级网评指令比例（月）详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcBjsjwpService.selectTcBjsjwpById(id));
    }

    /**
     * 新增本级上级网评指令比例（月）
     */
    @ApiOperation(value = "新增本级上级网评指令比例（月）")
    @PostMapping
    public AjaxResult add(@RequestBody TcBjsjwp tcBjsjwp)
    {
        return toAjax(tcBjsjwpService.insertTcBjsjwp(tcBjsjwp));
    }

    /**
     * 修改本级上级网评指令比例（月）
     */
    @ApiOperation(value = "修改本级上级网评指令比例（月）")
    @PutMapping
    public AjaxResult edit(@RequestBody TcBjsjwp tcBjsjwp)
    {
        return toAjax(tcBjsjwpService.updateTcBjsjwp(tcBjsjwp));
    }

    /**
     * 删除本级上级网评指令比例（月）
     */
    @ApiOperation(value = "删除本级上级网评指令比例（月）")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcBjsjwpService.deleteTcBjsjwpByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcBjsjwp> util = new ExcelUtil<TcBjsjwp>(TcBjsjwp.class);
        List<TcBjsjwp> tcBjsjwpList = util.importExcel(file.getInputStream());
        tcBjsjwpService.importUser(tcBjsjwpList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcBjsjwpService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }
    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcBjsjwp> util = new ExcelUtil<TcBjsjwp>(TcBjsjwp.class);
        util.importTemplateExcel(response, " 本级上级网评指令比例（月）");
    }
}
